==> apache-inlong-1.4.0-src.tar.gz: apache-inlong-1.4.0/inlong-sort/sort-formats/format-common/src/test/java/org/apache/inlong/sort/formats/common/ArrayFormatInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.common;

import java.util.Arrays;
import java.util.Collection;

/**
 * Unit tests for {@link ArrayFormatInfo}.
 */
public class ArrayFormatInfoTest extends FormatInfoTestBase {

    @Override
    Collection<FormatInfo> createFormatInfos() {
        ArrayFormatInfo formatInfo1 =
                new ArrayFormatInfo(StringFormatInfo.INSTANCE);

        ArrayFormatInfo formatInfo2 =
                new ArrayFormatInfo(
                        new ArrayFormatInfo(new DateFormatInfo("YYYY-MM-DD"))
                );

        ArrayFormatInfo formatInfo3 =
                new ArrayFormatInfo(
                        new MapFormatInfo(
                                StringFormatInfo.INSTANCE,
                                new ArrayFormatInfo(FloatFormatInfo.INSTANCE)
                        )
                );

        return Arrays.asList(formatInfo1, formatInfo2, formatInfo3);
    }
}

==> apache-inlong-1.10.0-src.tar.gz: apache-inlong-1.10.0/inlong-sort/sort-formats/format-common/src/test/java/org/apache/inlong/sort/formats/common/ArrayFormatInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.common;

import java.util.Arrays;
import java.util.Collection;

/**
 * Unit tests for {@link ArrayFormatInfo}.
 */
public class ArrayFormatInfoTest extends FormatInfoTestBase {

    @Override
    Collection<FormatInfo> createFormatInfos() {
        ArrayFormatInfo formatInfo1 =
                new ArrayFormatInfo(StringFormatInfo.INSTANCE);

        ArrayFormatInfo formatInfo2 =
                new ArrayFormatInfo(
                        new ArrayFormatInfo(new DateFormatInfo("YYYY-MM-DD")));

        ArrayFormatInfo formatInfo3 =
                new ArrayFormatInfo(
                        new MapFormatInfo(
                                StringFormatInfo.INSTANCE,
                                new ArrayFormatInfo(FloatFormatInfo.INSTANCE)));

        return Arrays.asList(formatInfo1, formatInfo2, formatInfo3);
    }
}
